@@ -285,8 +285,15 @@ load_meta_themes (GtkTreeView *tree_view,
   current_icon_theme = gconf_client_get_string (client, ICON_THEME_KEY, NULL);
   window_manager = gnome_wm_manager_get_current (gdk_display_get_default_screen (gdk_display_get_default ()));
   wm_settings.flags = GNOME_WM_SETTING_THEME;
-  gnome_window_manager_get_settings (window_manager, &wm_settings);
-  current_window_theme = g_strdup (wm_settings.theme);
+  if (window_manager)
+    {
+      gnome_window_manager_get_settings (window_manager, &wm_settings);
+      current_window_theme = g_strdup (wm_settings.theme);
+    }
+  else
+    {
+      current_window_theme = g_strdup ("");
+    }
 
   /* FIXME: What do we really do when there is no theme? */
   if (current_icon_theme == NULL)
@@ -294,7 +301,6 @@ load_meta_themes (GtkTreeView *tree_view,
   if (current_gtk_theme == NULL)
     current_gtk_theme = g_strdup ("Default");
 
-
   /* handle first time */
   if (first_time)
     {
@@ -310,7 +316,6 @@ load_meta_themes (GtkTreeView *tree_view,
   /* Sort meta_theme_list to be in the same order of the current data.  This way
    * we can walk through them together. */
   meta_theme_list = g_list_sort (meta_theme_list, sort_meta_theme_list_func);
-
   list = meta_theme_list;
   valid = gtk_tree_model_get_iter_first (model, &iter);
 
@@ -396,13 +401,12 @@ load_meta_themes (GtkTreeView *tree_view,
 	    {
 	      /* we insert a new item */
 	      GtkTreeIter iter_to_prepend;
-
 	      gtk_list_store_insert_before (GTK_LIST_STORE (model), &iter_to_prepend, &iter);
 	      blurb = g_strdup_printf ("<span size=\"larger\" weight=\"bold\">%s</span>\n%s",
 				       list_meta_theme_info->readable_name, list_meta_theme_info->comment);
 	      pixbuf = default_image;
 
-	      gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+	      gtk_list_store_set (GTK_LIST_STORE (model), &iter_to_prepend,
 				  META_THEME_PIXBUF_COLUMN, pixbuf,
 				  META_THEME_NAME_COLUMN, blurb,
 				  META_THEME_ID_COLUMN, list_meta_theme_info->name,
@@ -442,7 +446,6 @@ load_meta_themes (GtkTreeView *tree_view,
 	{
 	  /* It's a dead item. */
 	  GtkTreeIter iter_to_remove;
-
 	  iter_to_remove = iter;
 	  valid = gtk_tree_model_iter_next (model, &iter);
 	  gtk_list_store_remove (GTK_LIST_STORE (model), &iter_to_remove);
@@ -1002,7 +1005,6 @@ theme_changed_func (gpointer uri,
 		    gpointer user_data)
 {
   GladeXML *dialog;
-
   dialog = gnome_theme_manager_get_theme_dialog ();
 
   update_themes_from_disk (dialog);
@@ -1050,14 +1052,21 @@ setup_meta_tree_view (GtkTreeView *tree_view,
 					       G_TYPE_STRING,    /* META_THEME_ID_COLUMN     */
 					       G_TYPE_UINT,      /* META_THEME_FLAG_COLUMN   */
 					       GDK_TYPE_PIXBUF); /* META_THEME_PIXBUF_COLUMN */
-  gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model), 0, gnome_theme_manager_tree_sort_func, NULL, NULL);
-  gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model), 0, GTK_SORT_ASCENDING);
   gtk_tree_view_set_model (tree_view, model);
   selection = gtk_tree_view_get_selection (tree_view);
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
   g_signal_connect (G_OBJECT (selection), "changed", changed_callback, dialog);
 }
 
+
+static void
+gnome_meta_theme_installer_run_cb (GtkWidget *button,
+				   GtkWidget *parent_window)
+{
+  gnome_theme_installer_run (parent_window, NULL, FALSE);
+}
+
+
 static void
 gnome_theme_save_clicked (GtkWidget *button,
 			  gpointer   data)
@@ -1125,6 +1134,8 @@ setup_dialog (GladeXML *dialog)
   gtk_size_group_add_widget (size_group, WID ("meta_theme_background2_button"));
   g_object_unref (size_group);
 
+  g_signal_connect (G_OBJECT (WID ("meta_theme_install_button")), "clicked", G_CALLBACK (gnome_meta_theme_installer_run_cb), parent);
+
   g_signal_connect (G_OBJECT (WID ("meta_theme_details_button")), "clicked", gnome_theme_details_show, NULL);
 
   g_signal_connect (G_OBJECT (WID ("meta_theme_font1_button")), "clicked", G_CALLBACK (apply_font_clicked), dialog);
@@ -1220,48 +1231,6 @@ gnome_theme_manager_sort_func (const gchar *a_str,
   return retval;
 }
 
-gint
-gnome_theme_manager_tree_sort_func (GtkTreeModel *model,
-				    GtkTreeIter  *a,
-				    GtkTreeIter  *b,
-				    gpointer      user_data)
-{
-  GnomeThemeMetaInfo *a_meta_info;
-  GnomeThemeMetaInfo *b_meta_info;
-  gchar *a_id = NULL;
-  gchar *b_id = NULL;
-  guint a_flag = FALSE;
-  guint b_flag = FALSE;
-  gint retval;
-
-  gtk_tree_model_get (model, a,
-		      META_THEME_ID_COLUMN, &a_id,
-		      META_THEME_FLAG_COLUMN, &a_flag,
-		      -1);
-  gtk_tree_model_get (model, b,
-		      META_THEME_ID_COLUMN, &b_id,
-		      META_THEME_FLAG_COLUMN, &b_flag,
-		      -1);
-
-  if (a_id)
-    a_meta_info = gnome_theme_meta_info_find (a_id);
-  else
-    a_meta_info = &custom_meta_theme_info;
-  if (b_id)
-    b_meta_info = gnome_theme_meta_info_find (b_id);
-  else
-    b_meta_info = &custom_meta_theme_info;
-
-  retval = gnome_theme_manager_sort_func (a_meta_info?a_meta_info->readable_name:"",
-					  b_meta_info?b_meta_info->readable_name:"",
-					  a_flag, b_flag);
-
-  g_free (a_id);
-  g_free (b_id);
-
-  return retval;
-}
-
 /* Starts nautilus on the themes directory*/
 void
 gnome_theme_manager_show_manage_themes (GtkWidget *button, gpointer data)
@@ -1382,7 +1351,7 @@ gnome_theme_manager_drag_data_received_cb (GtkWidget *widget, GdkDragContext *co
 		gnome_vfs_uri_list_unref (uris);
 	}
 
-	gnome_theme_installer_run (widget, filename);
+	gnome_theme_installer_run (widget, filename, FALSE);
 	g_free (filename);
 }
 
@@ -1399,10 +1368,11 @@ main (int argc, char *argv[])
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  gnome_program_init ("gnome-theme-properties", VERSION,
+  gnome_program_init ("gnome-theme-manager", VERSION,
 		      LIBGNOMEUI_MODULE, argc, argv,
 		      GNOME_PARAM_APP_DATADIR, GNOMECC_DATA_DIR,
 		      NULL);
+  gnome_theme_init (NULL);
 
   gnome_wm_manager_init ();
   activate_settings_daemon ();
