@@ -418,7 +418,7 @@ sound_properties_add_defaults (SoundProperties *props, gchar *themedir)
 	sound_properties_freeze (props);
 	
 	i = 0;
-	path[i++] = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_CONFIG, "/sound/events", TRUE, NULL);
+	path[i++] = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_CONFIG, "sound/events", TRUE, NULL);
 	if (themedir)
 		path[theme = i++] = g_strdup (themedir);
 	path[i++] = gnome_util_home_file ("sound/events");
